function [SA_i, CT_i] = spline_interp_SA_CT(SA,CT,p,p_i)

% spline_interp_SA_CT              interpolation using spline 
%==========================================================================
%
% USAGE:
%  [SA_i,CT_i] = spline_interp_SA_CT(SA,CT,p,p_i)
%
% DESCRIPTION:
%  This function fits a spline-based curve using continuous curvature 
%  splines in tension.  The algorithm uses the Green's function for the 
%  spline.
%
% INPUT:
%  SA   =  Absolute Salinity                                  [ g/kg ]
%  CT   =  Conservative Temperature (ITS-90)                 [ deg C ]
%  p    =  sea pressure                                       [ dbar ]
%           ( i.e. absolute pressure - 10.1325 dbar )
%  p_i  =  pressures to interpolate to.
%
%  SA, CT and p need to have the same dimensions Mx1 or 1xN.
%
% OUTPUT:
%  SA_i = interpolated SA values at pressures p_i.
%  CT_i = interpolated CT values at pressures p_i.
%
% AUTHOR:  
%  21st July, 2016 by Paul Barker and Trevor McDougall. 
%
% VERSION NUMBER: 3.05.5 (17th January, 2015)
%
% References
%  Wessel, P., and D. Bercovici, 1998: Gridding with Splines in Tension: A
%   Green function Approach, Math. Geol., 30, 77-93.
%
%  The software is available from http://www.TEOS-10.org
%
%==========================================================================


SA = SA(:);
CT = CT(:);
p = p(:);
p_i = p_i(:);

SA_i = interp1(p,SA,p_i,'spline');
CT_i = interp1(p,CT,p_i,'spline');


end